==> Fred-Frechet-1.13.tar.gz: Fred-Frechet-1.13/include/dynamic_time_warping.hpp <==
/*
Copyright 2021 Dennis Rohde

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

#pragma once

#include <map>
#include <queue>

#include "types.hpp"
#include "point.hpp"
#include "interval.hpp"
#include "curve.hpp"
#include "random.hpp"
#include "config.hpp"

namespace Dynamic_Time_Warping {
    
namespace Discrete {
    
    struct Distance : public PDistance {
        explicit operator bool() const {
            return true;
        }
        
        std::string repr() const;
        
        std::vector<std::pair<curve_number_t, curve_number_t>> matching;
    };
    
    Points vertices_matching_points(const Curve&, const Curve&, Distance&);
    
    Distance distance(const Curve&, const Curve&);
}

}

==> Fred-Frechet-1.13.1.tar.gz: Fred-Frechet-1.13.1/include/dynamic_time_warping.hpp <==
/*
Copyright 2021 Dennis Rohde

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

#pragma once

#include <map>
#include <queue>

#include "types.hpp"
#include "point.hpp"
#include "interval.hpp"
#include "curve.hpp"
#include "random.hpp"
#include "config.hpp"

namespace Dynamic_Time_Warping {
    
namespace Discrete {
        
    struct Distance : public PDistance {
        explicit operator bool() const {
            return true;
        }
        
        std::string repr() const;
        
        std::vector<std::pair<curve_number_t, curve_number_t>> matching;
    };
    
    Points vertices_matching_points(const Curve&, const Curve&, const Distance&);
    
    Distance distance(const Curve&, const Curve&);
}

}
